@@ -364,7 +364,6 @@ bool ClarisDrawParser::readZone()
   if (!input->checkPosition(pos+4))
     return false;
   auto zoneSz=long(input->readULong(4));
-  std::string what("Unknown");
   if (zoneSz==0x44534554) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return readDSET().get()!=nullptr;
@@ -392,7 +391,7 @@ bool ClarisDrawParser::readZone()
   if (zoneSz==0)
     f << "_";
   else
-    f << "Entries(" << what << ")";
+    f << "Entries(Unknown)";
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
   input->seek(endPos, librevenge::RVNG_SEEK_SET);
@@ -1532,7 +1531,7 @@ std::shared_ptr<ClarisWksStruct::DSET> ClarisDrawParser::readDSET(bool isLibHead
     }
 
     long debPos = endPos-N*data0Length;
-    for (int i = 0; i < zone->m_numData; i++) {
+    for (long i = 0; i < zone->m_numData; i++) {
       input->seek(debPos, librevenge::RVNG_SEEK_SET);
       f.str("");
       f << "DSETU-" << i << ":";
@@ -1548,8 +1547,6 @@ std::shared_ptr<ClarisWksStruct::DSET> ClarisDrawParser::readDSET(bool isLibHead
     input->seek(endPos, librevenge::RVNG_SEEK_SET);
   }
 
-  if (!zone)
-    return zone;
   if (m_state->m_zonesMap.find(zone->m_id) != m_state->m_zonesMap.end()) {
     MWAW_DEBUG_MSG(("ClarisDrawParser::readDSET: zone %d already exists!!!!\n",
                     zone->m_id));
