@@ -731,18 +731,19 @@ bool CricketDrawParser::readShape()
       if (!col.isBlack())
         f << "color=" << col << ",";
       // set the gradient
+      auto &finalGrad=style.m_gradient;
       if (fountainType==3) {
-        style.m_gradientType=MWAWGraphicStyle::G_Radial;
-        style.m_gradientPercentCenter=MWAWVec2f(0.5f,0.5f); // fixme: use center and bdbox here
+        finalGrad.m_type=MWAWGraphicStyle::Gradient::G_Radial;
+        finalGrad.m_percentCenter=MWAWVec2f(0.5f,0.5f); // fixme: use center and bdbox here
       }
       else {
-        style.m_gradientType= MWAWGraphicStyle::G_Linear;
-        style.m_gradientAngle=float(angle+90);
+        finalGrad.m_type= MWAWGraphicStyle::Gradient::G_Linear;
+        finalGrad.m_angle=float(angle+90);
       }
-      style.m_gradientStopList.resize(2);
+      finalGrad.m_stopList.resize(2);
       for (size_t i=0; i<2; ++i)
-        style.m_gradientStopList[i]
-          =MWAWGraphicStyle::GradientStop(float(i),MWAWColor::barycenter(float(intensityVal[i])/100.f, col, float(100-intensityVal[i])/100.f, MWAWColor::white()));
+        finalGrad.m_stopList[i]
+          =MWAWGraphicStyle::Gradient::Stop(float(i),MWAWColor::barycenter(float(intensityVal[i])/100.f, col, float(100-intensityVal[i])/100.f, MWAWColor::white()));
     }
     f << "],";
   }
@@ -979,7 +980,7 @@ bool CricketDrawParser::readShape()
           float ang = (bord == limitAngle[0]) ? float(angle[0]) :
                       (bord == limitAngle[1]+1) ? float(angle[1]) : float(90 * bord);
           ang *= float(M_PI/180.);
-          float actVal[2] = { std::cos(ang), -std::sin(ang)};
+          float const actVal[2] = { std::cos(ang), -std::sin(ang)};
           if (actVal[0] < minVal[0]) minVal[0] = actVal[0];
           else if (actVal[0] > maxVal[0]) maxVal[0] = actVal[0];
           if (actVal[1] < minVal[1]) minVal[1] = actVal[1];
@@ -988,10 +989,10 @@ bool CricketDrawParser::readShape()
         MWAWBox2f circleBox(box);
         // we have the shape box, we need to reconstruct the circle box
         if (maxVal[0]>minVal[0] && maxVal[1]>minVal[1]) {
-          float scaling[2]= { (box[1][0]-box[0][0])/(maxVal[0]-minVal[0]),
-                              (box[1][1]-box[0][1])/(maxVal[1]-minVal[1])
-                            };
-          float constant[2]= { box[0][0]-minVal[0] *scaling[0], box[0][1]-minVal[1] *scaling[1]};
+          float const scaling[2]= { (box[1][0]-box[0][0])/(maxVal[0]-minVal[0]),
+                                    (box[1][1]-box[0][1])/(maxVal[1]-minVal[1])
+                                  };
+          float const constant[2]= { box[0][0]-minVal[0] *scaling[0], box[0][1]-minVal[1] *scaling[1]};
           circleBox=MWAWBox2f(MWAWVec2f(constant[0]-scaling[0], constant[1]-scaling[1]),
                               MWAWVec2f(constant[0]+scaling[0], constant[1]+scaling[1]));
         }
