@@ -83,6 +83,7 @@ struct Frame {
     , m_extra("")
   {
   }
+  Frame(Frame const &)=default;
   //! destructor
   virtual ~Frame();
   //! return the frame bdbox
@@ -167,6 +168,7 @@ std::ostream &operator<<(std::ostream &o, Frame const &grph)
     break;
   default:
     o << "#type=" << grph.m_type << ",";
+    break;
   case -1:
     break;
   }
@@ -580,7 +582,7 @@ struct TextBox final : public Frame {
       s << "textFileId=" << std::hex << m_textFileId << std::dec << ",";
     if (!m_linkedIdList.empty()) {
       s << "link[to]=[";
-      for (auto &id : m_linkedIdList)
+      for (auto const &id : m_linkedIdList)
         s << std::hex << id << std::dec << ",";
       s << "],";
     }
@@ -677,6 +679,9 @@ struct Pattern final : public MWAWGraphicStyle::Pattern {
     }
     m_percent=float(numOnes)/64.f;
   }
+  Pattern(Pattern const &)=default;
+  Pattern &operator=(Pattern const &)=default;
+  Pattern &operator=(Pattern &&)=default;
   //! destructor
   ~Pattern() final;
   //! the percentage
@@ -730,7 +735,7 @@ struct State {
 
   //! init the color list
   void initColors();
-  //! init the pattenr list
+  //! init the patterns' list
   void initPatterns();
 
   int m_numPages /* the number of pages */;
@@ -747,7 +752,7 @@ struct State {
 void State::initPatterns()
 {
   if (m_patternList.size()) return;
-  static uint16_t const(s_pattern[4*64]) = {
+  static uint16_t const s_pattern[4*64] = {
     0x0000, 0x0000, 0x0000, 0x0000, 0xffff, 0xffff, 0xffff, 0xffff, 0x7fff, 0xffff, 0xf7ff, 0xffff, 0x7fff, 0xf7ff, 0x7fff, 0xf7ff,
     0xffee, 0xffbb, 0xffee, 0xffbb, 0x77dd, 0x77dd, 0x77dd, 0x77dd, 0xaa55, 0xaa55, 0xaa55, 0xaa55, 0x8822, 0x8822, 0x8822, 0x8822,
     0xaa00, 0xaa00, 0xaa00, 0xaa00, 0xaa00, 0x4400, 0xaa00, 0x1100, 0x8800, 0xaa00, 0x8800, 0xaa00, 0x8800, 0x2200, 0x8800, 0x2200,
@@ -970,7 +975,7 @@ int HanMacWrdKGraph::numPages() const
   if (m_state->m_numPages)
     return m_state->m_numPages;
   int nPages = 0;
-  for (auto fIt : m_state->m_framesMap) {
+  for (auto const &fIt : m_state->m_framesMap) {
     if (!fIt.second) continue;
     int page = fIt.second->m_page+1;
     if (page <= nPages) continue;
@@ -989,7 +994,7 @@ bool HanMacWrdKGraph::sendText(long textId, long id, MWAWListenerPtr const &list
 std::map<long,int> HanMacWrdKGraph::getTextFrameInformations() const
 {
   std::map<long,int> mapIdType;
-  for (auto fIt : m_state->m_framesMap) {
+  for (auto const &fIt : m_state->m_framesMap) {
     if (!fIt.second) continue;
     auto const &frame = *fIt.second;
     std::vector<long> listId;
@@ -1586,16 +1591,16 @@ std::shared_ptr<HanMacWrdKGraphInternal::ShapeGraph> HanMacWrdKGraph::readShapeG
       float ang = (bord == limitAngle[0]) ? float(angles[0]) :
                   (bord == limitAngle[1]+1) ? float(angles[1]) : float(90 * bord);
       ang *= float(M_PI/180.);
-      float actVal[2] = { std::cos(ang), -std::sin(ang)};
+      float const actVal[2] = { std::cos(ang), -std::sin(ang)};
       if (actVal[0] < minVal[0]) minVal[0] = actVal[0];
       else if (actVal[0] > maxVal[0]) maxVal[0] = actVal[0];
       if (actVal[1] < minVal[1]) minVal[1] = actVal[1];
       else if (actVal[1] > maxVal[1]) maxVal[1] = actVal[1];
     }
-    float factor[2]= {bdbox.size()[0]/(maxVal[0]>minVal[0]?maxVal[0]-minVal[0]:0.f),
-                      bdbox.size()[1]/(maxVal[1]>minVal[1]?maxVal[1]-minVal[1]:0.f)
-                     };
-    float delta[2]= {bdbox[0][0]-minVal[0] *factor[0],bdbox[0][1]-minVal[1] *factor[1]};
+    float const factor[2]= {bdbox.size()[0]/(maxVal[0]>minVal[0]?maxVal[0]-minVal[0]:0.f),
+                            bdbox.size()[1]/(maxVal[1]>minVal[1]?maxVal[1]-minVal[1]:0.f)
+                           };
+    float const delta[2]= {bdbox[0][0]-minVal[0] *factor[0],bdbox[0][1]-minVal[1] *factor[1]};
     shape.m_formBox=MWAWBox2f(MWAWVec2f(delta[0]-factor[0],delta[1]-factor[1]),
                               MWAWVec2f(delta[0]+factor[0],delta[1]+factor[1]));
     shape.m_type=MWAWGraphicShape::Pie;
@@ -1623,7 +1628,6 @@ std::shared_ptr<HanMacWrdKGraphInternal::ShapeGraph> HanMacWrdKGraph::readShapeG
       if (val) f << "g" << i << "=" << val << ",";
     }
     shape.m_type=MWAWGraphicShape::Polygon;
-    MWAWVec2f minPt(0,0);
     for (int i = 0; i < numPt; ++i) {
       float dim[2];
       for (auto &d : dim) d = float(input->readLong(4))/65536.f;
@@ -1915,7 +1919,7 @@ std::shared_ptr<HanMacWrdKGraphInternal::Table> HanMacWrdKGraph::readTable(std::
     val = input->readLong(2);
     if (val) f << "f2=" << val << ",";
 
-    static char const *(what[]) = {"T", "L", "B", "R"};
+    static char const *what[] = {"T", "L", "B", "R"};
     static int const which[] = { libmwaw::TopBit, libmwaw::LeftBit, libmwaw::BottomBit, libmwaw::RightBit };
     for (int b = 0; b < 4; ++b) { // find _,4000,_,_,1,_, and 1,_,_,_,1,_,
       f2.str("");
@@ -2205,15 +2209,15 @@ void HanMacWrdKGraph::sendGroupChild(HanMacWrdKGraphInternal::Group const &group
 
 void HanMacWrdKGraph::prepareStructures()
 {
-  for (auto fIt : m_state->m_framesMap) {
+  for (auto const &fIt : m_state->m_framesMap) {
     if (!fIt.second) continue;
-    HanMacWrdKGraphInternal::Frame &frame = *fIt.second;
+    HanMacWrdKGraphInternal::Frame const &frame = *fIt.second;
     if (frame.m_type==11 && !frame.m_inGroup) {
       std::multimap<long, long> seens;
       checkGroupStructures(fIt.first, frame.m_fileSubId, seens, false);
     }
     if (frame.m_type==4) {
-      auto &text=static_cast<HanMacWrdKGraphInternal::TextBox &>(frame);
+      auto text=static_cast<HanMacWrdKGraphInternal::TextBox const &>(frame);
       size_t numLink=text.m_linkedIdList.size();
       for (size_t l=0; l < numLink; ++l) {
         auto fIt2=m_state->m_framesMap.find(text.m_linkedIdList[l]);
@@ -2269,9 +2273,9 @@ bool HanMacWrdKGraph::checkGroupStructures(long fileId, long fileSubId, std::mul
 bool HanMacWrdKGraph::sendPageGraphics(std::vector<long> const &doNotSendIds)
 {
   std::set<long> notSend;
-  for (auto &id : doNotSendIds)
+  for (auto const &id : doNotSendIds)
     notSend.insert(id);
-  for (auto fIt : m_state->m_framesMap) {
+  for (auto const &fIt : m_state->m_framesMap) {
     if (notSend.find(fIt.first) != notSend.end() || !fIt.second) continue;
     auto const &frame = *fIt.second;
     if (frame.m_parsed || frame.m_type==3 || frame.m_inGroup)
@@ -2286,7 +2290,7 @@ bool HanMacWrdKGraph::sendPageGraphics(std::vector<long> const &doNotSendIds)
 
 void HanMacWrdKGraph::flushExtra()
 {
-  for (auto fIt : m_state->m_framesMap) {
+  for (auto const &fIt : m_state->m_framesMap) {
     if (!fIt.second) continue;
     auto const &frame = *fIt.second;
     if (frame.m_parsed || frame.m_type==3)
@@ -2295,7 +2299,7 @@ void HanMacWrdKGraph::flushExtra()
     pos.setRelativePosition(MWAWPosition::Char);
     sendFrame(frame, pos);
   }
-  for (auto pIt : m_state->m_picturesMap) {
+  for (auto const &pIt : m_state->m_picturesMap) {
     if (!pIt.second) continue;
     auto const &picture = *pIt.second;
     if (picture.m_parsed)
