@@ -1015,7 +1015,7 @@ public:
   void getOdtInfo(int macId, std::string &nm, int &deltaSize);
 
   //! fixes the name corresponding to an id
-  void setCorrespondance(int macId, std::string const &name, std::string family="")
+  void setCorrespondance(int macId, std::string const &name, std::string const &family="")
   {
     m_idNameMap[macId] = name;
     m_nameIdMap[name] = macId;
@@ -1178,7 +1178,7 @@ void State::initMaps()
   m_idNameMap[101257] = "CP1257";
   m_idNameMap[101258] = "CP1258";
 
-  for (auto it : m_idNameMap)
+  for (auto const &it : m_idNameMap)
     m_nameIdMap[it.second] = it.first;
 }
 
