@@ -338,7 +338,7 @@ bool MacDocParser::sendContents()
   if (sendIndex())
     newPage(++actPage);
   listener->setParagraph(MWAWParagraph());
-  for (auto &it : m_state->m_idPictureMap) {
+  for (auto const &it : m_state->m_idPictureMap) {
     sendPicture(it.second);
     newPage(++actPage);
   }
@@ -696,7 +696,7 @@ bool MacDocParser::checkHeader(MWAWHeader *header, bool strict)
   }
   if (strict) {
     // check if at least one picture zone exists
-    auto &entryMap = getRSRCParser()->getEntriesMap();
+    auto const &entryMap = getRSRCParser()->getEntriesMap();
     if (entryMap.find("MDpg") == entryMap.end())
       return false;
   }
