@@ -61,7 +61,12 @@ namespace MoreParserInternal
 //! Internal: the state of a MoreParser
 struct State {
   //! constructor
-  State() : m_typeEntryMap(), m_backgroundColor(MWAWColor::white()), m_colorList(), m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0)
+  State()
+    : m_typeEntryMap()
+    , m_backgroundColor(MWAWColor::white())
+    , m_colorList()
+    , m_actPage(0)
+    , m_numPages(0)
   {
   }
   //! set the default color map
@@ -74,9 +79,6 @@ struct State {
   //! a list colorId -> color
   std::vector<MWAWColor> m_colorList;
   int m_actPage /** the actual page */, m_numPages /** the number of page of the final document */;
-
-  int m_headerHeight /** the header height if known */,
-      m_footerHeight /** the footer height if known */;
 };
 
 void State::setDefaultColorList(int version)
@@ -98,34 +100,29 @@ void State::setDefaultColorList(int version)
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a MoreParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
-  SubDocument(MoreParser &pars, MWAWInputStreamPtr input) :
-    MWAWSubDocument(&pars, input, MWAWEntry()) {}
+  SubDocument(MoreParser &pars, MWAWInputStreamPtr const &input)
+    : MWAWSubDocument(&pars, input, MWAWEntry())
+  {
+  }
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     if (MWAWSubDocument::operator!=(doc)) return true;
-    SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+    auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
     if (!sDoc) return true;
     return false;
   }
 
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
-
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
-protected:
 };
 
 void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*type*/)
@@ -143,8 +140,10 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MoreParser::MoreParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWTextParser(input, rsrcParser, header), m_state(), m_textParser()
+MoreParser::MoreParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWTextParser(input, rsrcParser, header)
+  , m_state()
+  , m_textParser()
 {
   init();
 }
@@ -182,7 +181,7 @@ libmwaw::DebugFile &MoreParser::rsrcAscii()
 MWAWVec2f MoreParser::getPageLeftTop() const
 {
   return MWAWVec2f(float(getPageSpan().getMarginLeft()),
-                   float(getPageSpan().getMarginTop()+m_state->m_headerHeight/72.0));
+                   float(getPageSpan().getMarginTop()));
 }
 
 bool MoreParser::checkAndStore(MWAWEntry const &entry)
@@ -233,7 +232,7 @@ void MoreParser::newPage(int number)
 
 bool MoreParser::getColor(int id, MWAWColor &col) const
 {
-  int numColor = static_cast<int>(m_state->m_colorList.size());
+  auto numColor = static_cast<int>(m_state->m_colorList.size());
   if (!numColor) {
     m_state->setDefaultColorList(version());
     numColor = int(m_state->m_colorList.size());
@@ -249,14 +248,14 @@ bool MoreParser::getColor(int id, MWAWColor &col) const
 ////////////////////////////////////////////////////////////
 void MoreParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
 
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
@@ -323,7 +322,6 @@ void MoreParser::createDocument(librevenge::RVNGTextInterface *documentInterface
 bool MoreParser::createZones()
 {
   int vers=version();
-  MWAWInputStreamPtr input = getInput();
   if (vers<2) {
     MWAW_DEBUG_MSG(("MoreParser::createZones: do not know how to createZone for v1\n"));
     return false;
@@ -331,8 +329,7 @@ bool MoreParser::createZones()
   if (!readZonesList())
     return false;
 
-  std::multimap<std::string, MWAWEntry>::const_iterator it;
-  it = m_state->m_typeEntryMap.find("PrintInfo");
+  auto it = m_state->m_typeEntryMap.find("PrintInfo");
   if (it != m_state->m_typeEntryMap.end())
     readPrintInfo(it->second);
 
@@ -375,9 +372,8 @@ bool MoreParser::createZones()
   if (it != m_state->m_typeEntryMap.end())
     readUnknown9(it->second);
 
-  it = m_state->m_typeEntryMap.begin();
-  while (it != m_state->m_typeEntryMap.end()) {
-    MWAWEntry const &entry=(it++)->second;
+  for (auto const &fIt : m_state->m_typeEntryMap) {
+    MWAWEntry const &entry=fIt.second;
     if (entry.isParsed())
       continue;
     libmwaw::DebugStream f;
@@ -409,7 +405,7 @@ bool MoreParser::readZonesList()
     MWAWEntry entry;
     entry.setBegin(long(input->readULong(4)));
     entry.setLength(long(input->readULong(4)));
-    static char const *(names[])= {
+    static char const *names[]= {
       "PrintInfo", "DocInfo", "Unknown2", "Topic",
       "Comment", "Slide", "Outline", "FreePos", "SpeakerNote"
     };
@@ -423,11 +419,11 @@ bool MoreParser::readZonesList()
       f << "###";
     }
   }
-  long unkn=long(input->readULong(4));
+  auto unkn=long(input->readULong(4));
   if (unkn) f << "unkn=" << unkn << ",";
   /* checkme: another list begins here, but I am not sure of its length :-~ */
   for (int i=0; i < 5; i++) {
-    static char const *(names[])=
+    static char const *names[]=
     { "Unknown9", "Fonts", "UnknownB","UnknownC", "UnknownD" };
     MWAWEntry entry;
     entry.setBegin(long(input->readULong(4)));
@@ -527,8 +523,7 @@ bool MoreParser::readDocumentInfo(MWAWEntry const &entry)
   f << "Entries(DocInfo):";
   entry.setParsed(true);
   double margins[4]; // LR TB
-  for (int i=0; i < 4; i++)
-    margins[i]=double(input->readULong(2))/1440.;
+  for (auto &margin : margins) margin=double(input->readULong(2))/1440.;
   f << "margins=" << margins[0] << "x" << margins[2]
     << "<->" << margins[1] << "x" << margins[3] << ",";
   int val;
@@ -537,8 +532,7 @@ bool MoreParser::readDocumentInfo(MWAWEntry const &entry)
     if (val!=1) f << "fl" << i << "=" << val << ",";
   }
   double dim[3];
-  for (int i=0; i < 3; i++)
-    dim[i]=double(input->readULong(2))/72.;
+  for (auto &d: dim) d=double(input->readULong(2))/72.;
   f << "dim=" << dim[0] << "x" << dim[1];
   if (dim[1]<dim[2]||dim[1]>dim[2])
     f << "[" << dim[2] << "],";
@@ -595,8 +589,7 @@ bool MoreParser::readDocumentInfo(MWAWEntry const &entry)
   for (int st=0; st <7; st++) {
     // normal white,white,black,white,black,background=white,white
     unsigned char color[3];
-    for (int i=0; i < 3; i++)
-      color[i]=static_cast<unsigned char>(input->readULong(2)>>8);
+    for (auto &c : color) c=static_cast<unsigned char>(input->readULong(2)>>8);
     MWAWColor col(color[0], color[1], color[2]);
     if (st==2 || st==4) {
       if (col.isBlack())
@@ -643,7 +636,7 @@ bool MoreParser::readFreePos(MWAWEntry const &entry)
   entry.setParsed(true);
 
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  int N=static_cast<int>(input->readULong(4));
+  auto N=static_cast<int>(input->readULong(4));
   f << "Entries(FreePos):N=" << N;
   if (N > (entry.length() - 4) / 8) {
     MWAW_DEBUG_MSG(("MoreParser::readFreePos: the number of entry seems bad\n"));
@@ -680,7 +673,7 @@ bool MoreParser::readFreePos(MWAWEntry const &entry)
     seenPos.insert(fPos);
     MWAWEntry tEntry;
     tEntry.setBegin(fPos);
-    int what=static_cast<int>(input->readULong(2));
+    auto what=static_cast<int>(input->readULong(2));
     if (what==0) {
       tEntry.setLength(static_cast<int>(input->readULong(2)));
       f << "length=" << tEntry.length() << ",";
@@ -710,8 +703,7 @@ bool MoreParser::readFreePos(MWAWEntry const &entry)
   ascii().addPos(entry.end());
   ascii().addNote("_");
 
-  for (size_t i=0; i < filePositions.size(); i++) {
-    MWAWEntry const &tEntry=filePositions[i];
+  for (auto const &tEntry : filePositions) {
     ascii().addPos(tEntry.begin());
     ascii().addNote("FreePos-data:");
     ascii().addPos(tEntry.end());
@@ -734,7 +726,7 @@ bool MoreParser::checkHeader(MWAWHeader *header, bool strict)
   libmwaw::DebugStream f;
   f << "FileHeader:";
   input->seek(0,librevenge::RVNG_SEEK_SET);
-  int val=static_cast<int>(input->readLong(2));
+  auto val=static_cast<int>(input->readLong(2));
   int vers;
   switch (val) {
   case 3:
@@ -795,7 +787,7 @@ bool MoreParser::readSlideList(MWAWEntry const &entry)
   ascii().addPos(pos);
   ascii().addNote("Entries(Slide)");
 
-  int N=int(entry.length()/8);
+  auto N=int(entry.length()/8);
   std::vector<MWAWEntry> filePositions;
   for (int i=0; i < N; i++) {
     pos=input->tell();
@@ -814,7 +806,7 @@ bool MoreParser::readSlideList(MWAWEntry const &entry)
     }
     else
       filePositions.push_back(tEntry);
-    int val = static_cast<int>(input->readLong(2)); // always -1 ?
+    auto val = static_cast<int>(input->readLong(2)); // always -1 ?
     if (val != -1)
       f << "f0=" << val << ",";
     val = static_cast<int>(input->readLong(2)); // always 0 ?
@@ -825,12 +817,12 @@ bool MoreParser::readSlideList(MWAWEntry const &entry)
     ascii().addNote(f.str().c_str());
     input->seek(pos+8, librevenge::RVNG_SEEK_SET);
   }
-  for (size_t i=0; i < filePositions.size(); i++) {
-    MWAWEntry const &tEntry=filePositions[i];
+  int n=0;
+  for (auto const &tEntry : filePositions) {
     if (readSlide(tEntry))
       continue;
     f.str("");
-    f << "Slide-###" << i << "[data]:";
+    f << "Slide-###" << n++ << "[data]:";
     ascii().addPos(tEntry.begin());
     ascii().addNote(f.str().c_str());
     ascii().addPos(tEntry.end());
@@ -863,7 +855,7 @@ bool MoreParser::readSlide(MWAWEntry const &entry)
     pos = input->tell();
     if (pos+2 > endPos)
       break;
-    int type=static_cast<int>(input->readLong(2));
+    auto type=static_cast<int>(input->readLong(2));
     int dataSz=0;
     if (type & 0x1)
       dataSz=4;
@@ -934,7 +926,7 @@ bool MoreParser::readGraphic(MWAWEntry const &entry)
   input->seek(pos, librevenge::RVNG_SEEK_SET);
 
   // first check
-  int readSize = int(input->readULong(2));
+  auto readSize = int(input->readULong(2));
   input->seek(8, librevenge::RVNG_SEEK_CUR); // skip dim
   long lastFlag = input->readLong(2);
   switch (lastFlag) {
@@ -993,7 +985,7 @@ bool MoreParser::readUnknown9(MWAWEntry const &entry)
 
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(Unknown9):";
-  int N=static_cast<int>(input->readLong(4));
+  auto N=static_cast<int>(input->readLong(4));
   f << "N=" << N << ",";
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -1007,9 +999,9 @@ bool MoreParser::readUnknown9(MWAWEntry const &entry)
         continue;
       input->seek(pos, librevenge::RVNG_SEEK_SET);
     }
-    int type=static_cast<int>(input->readULong(2)); // find 1: color 2:?
+    auto type=static_cast<int>(input->readULong(2)); // find 1: color 2:?
     if (type > 10) break;
-    long dataSz = long(input->readULong(4));
+    auto dataSz = long(input->readULong(4));
     if (dataSz<= 0 || pos+6+dataSz > endPos) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       break;
@@ -1076,14 +1068,14 @@ bool MoreParser::readColors(long endPos)
 
   libmwaw::DebugStream f;
   f << "Entries(ColorL):";
-  long dataSz=long(input->readULong(4));
+  auto dataSz=long(input->readULong(4));
   if (pos+6+dataSz > endPos)
     return false;
   long val= input->readLong(4); // 3ff or 413 a size ?
   if (val) f << "f0=" << val << ",";
   val= input->readLong(2); // always 0
   if (val) f << "f1=" << val << ",";
-  int maxCols=static_cast<int>(input->readLong(2));
+  auto maxCols=static_cast<int>(input->readLong(2));
   f << "nCol=" << maxCols << ",";
   if (maxCols<0 || 16+8*maxCols != dataSz)
     return false;
@@ -1093,11 +1085,10 @@ bool MoreParser::readColors(long endPos)
     pos=input->tell();
     f.str("");
     f << "ColorL" << i << ",";
-    int id=static_cast<int>(input->readLong(2));
+    auto id=static_cast<int>(input->readLong(2));
     if (id!=i) f << "#id=" << id << ",";
     unsigned char rgb[3];
-    for (int c=0; c<3; c++)
-      rgb[c]=static_cast<unsigned char>(input->readULong(2)>>8);
+    for (auto &c : rgb) c=static_cast<unsigned char>(input->readULong(2)>>8);
     MWAWColor col(rgb[0], rgb[1], rgb[2]);
     f << "col=" << col << ",";
     ascii().addPos(pos);
@@ -1123,7 +1114,7 @@ bool MoreParser::readBackside(long endPos, std::string &extra)
     return false;
 
   libmwaw::DebugStream f;
-  int val=static_cast<int>(input->readULong(1)); // small number between 1 and 8
+  auto val=static_cast<int>(input->readULong(1)); // small number between 1 and 8
   f << "f0=" << val << ",";
   val=static_cast<int>(input->readLong(1)); // always 0 ?
   if (val) f << "f1=" << val << ",";
@@ -1132,13 +1123,11 @@ bool MoreParser::readBackside(long endPos, std::string &extra)
     if (val) f << "f" << i+2 << "=" << val << ",";
   }
   int center[2]; // checkme: xy
-  for (int i=0; i < 2; i++)
-    center[i]=static_cast<int>(input->readLong(2));
+  for (auto &c : center) c=static_cast<int>(input->readLong(2));
   if (center[0]!=500 || center[1]!=500)
     f << "center=" << center[0] << "x" << center[1] << ",";
   int dim[4];
-  for (int i=0; i < 4; i++)
-    dim[i]=static_cast<int>(input->readLong(2));
+  for (auto &d : dim) d=static_cast<int>(input->readLong(2));
   if (dim[0] || dim[1] || dim[2]!=1000 || dim[3]!=1000)
     f << "dim=" << dim[0] << "x" << dim[1] << "<->" << dim[2] << "x" << dim[3] << ",";
   for (int i=0; i < 2; i++) { // g0: small number between 1 and a, g1:16*small number
@@ -1146,11 +1135,9 @@ bool MoreParser::readBackside(long endPos, std::string &extra)
     if (val) f << "g" << i << "=" << val << ",";
   }
   unsigned char rgb[3];
-  for (int c=0; c<3; c++)
-    rgb[c]=static_cast<unsigned char>(input->readULong(2)>>8);
+  for (auto &c: rgb) c=static_cast<unsigned char>(input->readULong(2)>>8);
   f << "col0=" << MWAWColor(rgb[0], rgb[1], rgb[2]) << ",";
-  for (int c=0; c<3; c++)
-    rgb[c]=static_cast<unsigned char>(input->readULong(2)>>8);
+  for (auto &c: rgb) c=static_cast<unsigned char>(input->readULong(2)>>8);
   f << "col1=" << MWAWColor(rgb[0], rgb[1], rgb[2]) << ",";
   extra=f.str();
   return true;
@@ -1171,16 +1158,13 @@ bool MoreParser::readPattern(long endPos, MoreStruct::Pattern &pattern)
   if (name != "BACKPTRN")
     return false;
 
-  for (int i=0; i < 8; i++)
-    pattern.m_pattern[i] = static_cast<unsigned char>(input->readULong(1));
+  for (auto &data : pattern.m_pattern) data = static_cast<unsigned char>(input->readULong(1));
 
   // checkme: in general frontColor=backColor, but not always...
   unsigned char rgb[3];
-  for (int c=0; c<3; c++)
-    rgb[c]=static_cast<unsigned char>(input->readULong(2)>>8);
+  for (auto &c : rgb) c=static_cast<unsigned char>(input->readULong(2)>>8);
   pattern.m_frontColor=MWAWColor(rgb[0], rgb[1], rgb[2]);
-  for (int c=0; c<3; c++)
-    rgb[c]=static_cast<unsigned char>(input->readULong(2)>>8);
+  for (auto &c : rgb) c=static_cast<unsigned char>(input->readULong(2)>>8);
   pattern.m_backColor=MWAWColor(rgb[0], rgb[1], rgb[2]);
   return true;
 }
@@ -1259,7 +1243,7 @@ bool MoreParser::readUnkn9Sub(long endPos)
 
   pos=debPos+116;
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  int N=static_cast<int>(input->readLong(2));
+  auto N=static_cast<int>(input->readLong(2));
   f.str("");
   f << "Unkn9A-III:N=" << N << ",";
   if (pos+2+(N+1)*8 > endPos) {
@@ -1295,8 +1279,8 @@ namespace MoreStruct
 std::ostream &operator<<(std::ostream &o, Pattern const &pat)
 {
   o << "pat=[" << std::hex;
-  for (int i=0; i<8; i++)
-    o << int(pat.m_pattern[i]) << ",";
+  for (auto data : pat.m_pattern)
+    o << data << ",";
   o << std::dec << "],";
   if (!pat.m_frontColor.isBlack())
     o << "frontColor=" << pat.m_frontColor << ",";
