@@ -640,7 +640,7 @@ bool PowerPoint1Parser::readListZones(int &docInfoId)
 
   // check that the zones do not overlap
   for (size_t i=0; i<m_state->m_zonesList.size(); ++i) {
-    MWAWEntry &zone=m_state->m_zonesList[size_t(i)];
+    MWAWEntry const &zone=m_state->m_zonesList[size_t(i)];
     if (!zone.valid()) continue;
     auto it=posList.find(zone.begin());
     bool ok=it!=posList.end();
@@ -936,7 +936,7 @@ bool PowerPoint1Parser::readFramesList(MWAWEntry const &entry, std::vector<Power
           style.m_arrows[0]=style.m_arrows[1]=MWAWGraphicStyle::Arrow::plain();
           f << "arrow[beg,end],";
         }
-        else if (val) {
+        else {
           MWAW_DEBUG_MSG(("PowerPoint1Parser::readFramesList: find unexpected arrow\n"));
           f << "##arrow=" << val << ",";
         }
