@@ -2810,7 +2810,7 @@ void PowerPoint7Parser::sendSlides()
     MWAW_DEBUG_MSG(("PowerPoint7Parser::sendSlides: can not find the listener\n"));
     return;
   }
-  for (auto mIt : m_state->m_masterSlideIdToNameMap) {
+  for (auto const &mIt : m_state->m_masterSlideIdToNameMap) {
     if (!mIt.first.isValid()) continue;
     MWAWPageSpan ps(getPageSpan());
     ps.setMasterPageName(mIt.second);
