@@ -444,8 +444,8 @@ void ScoopParser::createDocument(librevenge::RVNGDrawingInterface *documentInter
       ps.setFormLength(ps.getFormLength()*m_state->m_thumbnailSize[1]);
       ps.setPageSpan(1);
       pageList.push_back(ps);
-      numPages-=m_state->m_thumbnailSize[0]*m_state->m_thumbnailSize[1];
-      numPages=std::max<int>(0,m_state->m_numPages);
+      numPages/=m_state->m_thumbnailSize[0]*m_state->m_thumbnailSize[1];
+      numPages=std::max<int>(0,numPages);
     }
   }
   if (numPages || m_state->m_hasScrapPage) {
@@ -563,7 +563,7 @@ bool ScoopParser::send(ScoopParserInternal::Shape const &shape, MWAWVec2i const
       float ang = (bord == limitAngle[0]) ? float(angle[0]) :
                   (bord == limitAngle[1]+1) ? float(angle[1]) : float(90 * bord);
       ang *= float(M_PI/180.);
-      float actVal[2] = { axis[0] *std::cos(ang), -axis[1] *std::sin(ang)};
+      float const actVal[2] = { axis[0] *std::cos(ang), -axis[1] *std::sin(ang)};
       if (actVal[0] < minVal[0]) minVal[0] = actVal[0];
       else if (actVal[0] > maxVal[0]) maxVal[0] = actVal[0];
       if (actVal[1] < minVal[1]) minVal[1] = actVal[1];
@@ -905,7 +905,6 @@ bool ScoopParser::readTextZone(ScoopParserInternal::TextZone &tZone)
     return false;
 
   // first look for name style
-  pos=input->tell();
   while (!input->isEnd()) {
     pos=input->tell();
     val=int(input->readULong(4));
@@ -1026,7 +1025,7 @@ bool ScoopParser::readTextZone(ScoopParserInternal::TextZone &tZone)
       f.str("");
       f << "TextZone-wrap" << n << ":";
       long len=long(input->readULong(4));
-      if (len<0 || pos+4+len<pos+4 || !input->checkPosition(pos+4+len)) {
+      if (len<0 || (long)((unsigned long)pos+4+(unsigned long)len)<pos+4 || !input->checkPosition(pos+4+len)) {
         input->seek(pos, librevenge::RVNG_SEEK_SET);
         MWAW_DEBUG_MSG(("ScoopParser::readTextZone: can find some find the round around zone\n"));
         return false;
@@ -1217,7 +1216,7 @@ bool ScoopParser::readTextZoneParagraph(ScoopParserInternal::Paragraph &para, in
   if (numKerns) {
     pos=input->tell();
     long len=long(input->readULong(4));
-    if (len<0 || pos+4+len<pos+4 || !input->checkPosition(pos+4+len)) {
+    if (len<0 || (long)((unsigned long)pos+4+(unsigned long)len)<pos+4 || !input->checkPosition(pos+4+len)) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       MWAW_DEBUG_MSG(("ScoopParser::readTextZoneParagraph: can find the kerns' zone\n"));
       return false;
@@ -1444,7 +1443,7 @@ bool ScoopParser::readParagraph(MWAWParagraph &para, bool define)
     f.str("");
     f << "PStyle-tabs:";
     long len=long(input->readLong(4));
-    if (len<0 || pos+4+len<pos+4 || !input->checkPosition(pos+4+len)) {
+    if (len<0 || (long)((unsigned long)pos+4+(unsigned long)len)<pos+4 || !input->checkPosition(pos+4+len)) {
       f << "###";
       MWAW_DEBUG_MSG(("ScoopParser::readParagraph: unexpected tabs length\n"));
       ascii().addPos(pos);
@@ -1503,7 +1502,7 @@ bool ScoopParser::readText(MWAWEntry &entry, std::string const &what)
 
   f << "TextZone-" << what << ":";
   long len=long(input->readULong(4));
-  if (pos+4+len<pos+4 || !input->checkPosition(pos+4+len)) {
+  if ((long)((unsigned long)pos+4+(unsigned long)len)<pos+4 || !input->checkPosition(pos+4+len)) {
     f << "###";
     MWAW_DEBUG_MSG(("ScoopParser::readText:can not find the text\n"));
     ascii().addPos(pos);
@@ -1780,7 +1779,7 @@ bool ScoopParser::readShape(ScoopParserInternal::Shape &shape, int id)
       continue;
     pos=input->tell();
     long len=long(input->readULong(4));
-    if (pos+4+len<pos+4 || !input->checkPosition(pos+4+len)) {
+    if ((long)((unsigned long)pos+4+(unsigned long)len)<pos+4 || !input->checkPosition(pos+4+len)) {
       MWAW_DEBUG_MSG(("ScoopParser::readShape: can not find a child at position=%lx\n", (unsigned long) pos));
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       return true;
@@ -1928,7 +1927,7 @@ bool ScoopParser::checkHeader(MWAWHeader *header, bool strict)
   libmwaw::DebugStream f;
   f << "FileHeader:";
   input->seek(0, librevenge::RVNG_SEEK_SET);
-  if (input->readULong(4)!=0 && input->readULong(4)!=0x70 && input->readULong(2)!=0x1100) return false;
+  if (input->readULong(4)!=0 || input->readULong(4)!=0x70 || input->readULong(2)!=0x1100) return false;
 
   if (strict) {
     // look for the printer information structure
